@@ -84,7 +84,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
             });
         parentLocalesMap.put(Locale.forLanguageTag("no"),
             new String[] {
-                "", "nb", "nn", 
+                "", "nb", "nn", "no-NO", 
             });
         parentLocalesMap.put(Locale.forLanguageTag("en-IN"),
             new String[] {
@@ -523,6 +523,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
             tzCanonicalIDMap.put("bddac", "Asia/Dhaka");
             tzCanonicalIDMap.put("Asia/Dacca", "Asia/Dhaka");
             tzCanonicalIDMap.put("cator", "America/Toronto");
+            tzCanonicalIDMap.put("America/Montreal", "America/Toronto");
             tzCanonicalIDMap.put("Canada/Eastern", "America/Toronto");
             tzCanonicalIDMap.put("cgbzv", "Africa/Brazzaville");
             tzCanonicalIDMap.put("tldil", "Asia/Dili");
